package com.ruoyi.info.collection.service;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.ruoyi.info.collection.domain.dto.CcdiEnterpriseBaseInfoAddDTO;
import com.ruoyi.info.collection.domain.dto.CcdiEnterpriseBaseInfoEditDTO;
import com.ruoyi.info.collection.domain.dto.CcdiEnterpriseBaseInfoQueryDTO;
import com.ruoyi.info.collection.domain.excel.CcdiEnterpriseBaseInfoExcel;
import com.ruoyi.info.collection.domain.vo.CcdiEnterpriseBaseInfoVO;

import java.util.List;

/**
 * 实体库管理 Service 接口
 *
 * @author ruoyi
 * @date 2026-04-17
 */
public interface ICcdiEnterpriseBaseInfoService {

    Page<CcdiEnterpriseBaseInfoVO> selectEnterpriseBaseInfoPage(Page<CcdiEnterpriseBaseInfoVO> page,
                                                                CcdiEnterpriseBaseInfoQueryDTO queryDTO);

    CcdiEnterpriseBaseInfoVO selectEnterpriseBaseInfoById(String socialCreditCode);

    int insertEnterpriseBaseInfo(CcdiEnterpriseBaseInfoAddDTO addDTO);

    int updateEnterpriseBaseInfo(CcdiEnterpriseBaseInfoEditDTO editDTO);

    int deleteEnterpriseBaseInfoByIds(String[] socialCreditCodes);

    List<CcdiEnterpriseBaseInfoExcel> selectEnterpriseBaseInfoListForExport(CcdiEnterpriseBaseInfoQueryDTO queryDTO);

    String importEnterpriseBaseInfo(List<CcdiEnterpriseBaseInfoExcel> excelList);
}
